# This is the code to reproduce the results of the article
# "Contingent valuation of measures against urban heat: limitations of a frequently used method."
# to be published in the Journal of Urban Planning and Development
# The code is prepared for the open source software R (www.r-project.org)

# NOTE for myself: First run "dataprepMarkdown_v006.Rmd", then 
# run "UHI_weights_v011.R"  to the line "save(all, file="ReplicationData.RData")"


# laod the following packages 
# (install them first with the command install.packages("packagename") if you have not done so previously)

 library(survey)   # version 3.30-3
 library(lmtest)   # version 0.9-33
 library(sandwich) # version 2.3-4
 library(weights)  # version 0.80
 library(boot)     # version  1.3-15
 
# clear whatever is in your wording environment
  rm(list=ls())

# set the working directory
  # you need to set this according to where you saved your file "ReplicationData_v002.RData" and the files ending with ".R" to.
 setwd("E:/myDirectory/supplementalData/DataAndCode") # take care to use "/", also on windows systems

# load the data "ReplicationData_v002.RData"
# you need to download the data first from the journals webpage
# and place them in the working directory you specified above

 load("ReplicationData_v002.RData")

 # export data to csv file  
 # write.csv(all, "ReplicationData_v002.csv", row.names = FALSE)

######################
# make a survey design object
# set the number of households in Vienna 
 households<-871371
 
# drop observations used for raking but have NAs
all.design<-all[!is.na(all$car)&
                #!is.na(all$personal_incom_quartil)&
                #!is.na(all$hh_persons_STATaust)&
                !is.na(all$dogOwn)&
                !is.na(all$pension)&
                !is.na(all$age)&
                !is.na(all$gender)&
                !is.na(all$universitydegree)&
                !(is.na(all$X8_trees_yes)& all$scenario =="trees")&
                !(is.na(all$X8_fountain_yes) & all$scenario =="fountains")&
                !(is.na(all$X8_beide_yes) & all$scenario =="both")
                ,]
 rm(all)
 # determine responses per stratum
   all.design$temp<-1
   all.design$responsesStratum<-ave(all.design$temp, all.design$stratum,FUN=sum)
   all.design$temp<-NULL
 # determine analytical weights for the sample as a whole and for each of the szenarios spearately
   all.design$weights_all<-all.design$stratumNumberHH/all.design$responsesStratum 
   all.design$weights_tree[all.design$scenario=="trees"]<-  all.design$stratumNumberHH[all.design$scenario=="trees"]/all.design$responsesStratum[all.design$scenario=="trees"]
   all.design$weights_foun[all.design$scenario=="fountains"]<-  all.design$stratumNumberHH[all.design$scenario=="fountains"]/all.design$responsesStratum[all.design$scenario=="fountains"]
   all.design$weights_both[all.design$scenario=="both"]<-  all.design$stratumNumberHH[all.design$scenario=="both"]/all.design$responsesStratum[all.design$scenario=="both"]
   all.design$weights_treeboth[all.design$scenario=="trees"|all.design$scenario=="both"]<-  all.design$stratumNumberHH[all.design$scenario=="trees"|all.design$scenario=="both"]/all.design$responsesStratum[all.design$scenario=="trees"|all.design$scenario=="both"]
   all.design$weights_founboth[all.design$scenario=="fountains"|all.design$scenario=="both"]<-  all.design$stratumNumberHH[all.design$scenario=="fountains"|all.design$scenario=="both"]/all.design$responsesStratum[all.design$scenario=="fountains"|all.design$scenario=="both"]

 # make survey desing objects
    uhi_design_all <- svydesign(id=~block_blockno,#+token, 
                             strata=~stratum,
                             weights=~weights_all, #not necessary if prob is provided
                             fpc=~stratumNumberHH,
                             data=all.design[,] )

   uhi_design_tree <- svydesign(id=~block_blockno,
                        strata=~stratum,
                        weights=~weights_tree, 
                        data=all.design[all.design$scenario=="trees",] )

   uhi_design_foun <- svydesign(id=~block_blockno,
                             strata=~stratum,
                             weights=~weights_foun, 
                             data=all.design[all.design$scenario=="fountains",] )

   uhi_design_both <- svydesign(id=~block_blockno,
                             strata=~stratum,
                             weights=~weights_both, 
                             data=all.design[all.design$scenario=="both",] )


   uhi_design_treeboth <- svydesign(id=~block_blockno,
                             strata=~stratum,
                             weights=~weights_treeboth,
                             data=all.design[all.design$scenario=="trees"|all.design$scenario=="both",] )

   uhi_design_founboth <- svydesign(id=~block_blockno,
                                 strata=~stratum,
                                 weights=~weights_founboth, 
                                 data=all.design[all.design$scenario=="fountains"|all.design$scenario=="both",] )

#################################
#
# Population shares:
#
#################################
    
   
   ##################
    # Ownership of cars (PKW)  
     # Source: Statistik Austria
     # http://www.statistik.at/web_de/statistiken/soziales/ausstattung_privater_haushalte/059000.html
     # Share of households in Vienna with one car: 0.59
     # Share of househlds with more than wone car: 0.09
     # --> 0 car: 1-0.59; 1 car: 0.59-0.9=0.5, more than 2 car: 0.09

      pop.pkw <-  data.frame("car"=levels(all.design$car), Freq=c((1-0.59)*households,(1-.5)*households, (0.09)*households) )
       comparision.car<-  rbind (table(all.design$car)/sum(table(all.design$car)), pop.pkw[,2]/sum(pop.pkw[,2]))
       rownames(comparision.car)<-c("survey", "Official Statistic")
       z <- (comparision.car[1,]-comparision.car[2,])/((comparision.car[2,]*(1-comparision.car[2,]))/385)^.5
       p.value<-(1-(pnorm(abs(z))))*2
      
      comparision.car<-cbind(comparision.car[,1],c(p.value[1],NA),
                       comparision.car[,2],c(p.value[2],NA),
                       comparision.car[,3],c(p.value[3],NA))
    ###########                        
    # Tree density
     # GIS data on street trees and Zaehlbezirk (administrative unit) bounderies
     # are available from the city of Vienna at open.wien.at   
     # Besed on this we derived the density (=number of trees per Zaehlbezirk  divided by m^2 of Zaehlbezirk)
     # The median density was used to group the Zahelgebiete (smaller adminstrative unit) in two groups
     # As we know how many households live in which Zahlgebiet we know the population distribution between the two groups  
      pop.treeDensityClasses <-data.frame("treeDensityClasses"=c("1","2"), Freq=c(446172, 425199))
      comparision.treeDensityClasses<-  rbind (table(all.design$treeDensityClasses)/sum(table(all.design$treeDensityClasses)), 
                                         pop.treeDensityClasses[,2]/sum(pop.treeDensityClasses[,2]))

        rownames(comparision.treeDensityClasses)<-c("survey", "Official Statistic")
        z <- (comparision.treeDensityClasses[1,]-comparision.treeDensityClasses[2,])/((comparision.treeDensityClasses[2,]*(1-comparision.treeDensityClasses[2,]))/385)^.5
        p.value<-(1-(pnorm(abs(z))))*2
        comparision.treeDensityClasses<-cbind(comparision.treeDensityClasses[,1],c(p.value[1],NA),
                                     comparision.treeDensityClasses[,2],c(p.value[2],NA)
                                )
  ##########
  # Education
    # Based on    
    # Statistical yearbook of Vienna 2013
    # https://www.wien.gv.at/statistik/publikationen/jahrbuch.html        
    # Education of 25-64 years  old in 2010
    # Number of persones between 25-64 years: 967270 
    # Mandatory schooling: 222866 
    # Lehre: 243546
    # Berufsbildende mittlere Schule: 109067
    # High School (A-levels): 175303
    # Similar too university: 32565
    # University and related: 183923
    # "Hochschulverwandte Lehranstalt" and "Universität, Hochschule, Fachhochschule"
    #
    # the following shares of education levels are weighted by the share of households over the total number of 25-64 years old persons
    # these are used for raking
    pop.education  <-  data.frame("education2"=factor(1:4), 
                           "Freq"=c((222866+243546) *(households/967270), # 967270  is the total number of 25-64 year old persons
                                    #243546 *(households/967270),
                                    109067 *(households/967270),
                                    175303 *(households/967270),
                                    (32565+183923) *(households/967270))
                         )
    # unweighted data
    # we use thses data for to compare population shares
        pop.educationOrig  <-  data.frame("education2"=factor(1:4), 
                              "Freq"=c(222866+243546,109067,175303,32565+183923)
                               )
        comparision.education<-  rbind (table(all.design$education2,exclude=NA , useNA="no" )/nrow(all.design), 
                                       pop.educationOrig[,2]/sum(pop.educationOrig[,2])
                                     )


        rownames(comparision.education)<-c("survey", "Official Statistic")
        comparision.education
        z <- (comparision.education[1,]-comparision.education[2,])/((comparision.education[2,]*(1-comparision.education[2,]))/385)^.5
        p.value<-(1-(pnorm(abs(z))))*2
        comparision.education<-cbind(comparision.education[,1],c(p.value[1],NA),
                             comparision.education[,2],c(p.value[2],NA),
                             comparision.education[,3],c(p.value[3],NA),
                             comparision.education[,4],c(p.value[4],NA)
                            )
       # We assume that the share of persons with university degree in the population
       # equals the share of households where the person which responds to surveys
       # like ours has an university degree
     summary(lm(personal_incom_cont~education2, data=all.design))
    
   #########
   # Retiered persons
    # Source: Statistik Austria  "STATcube" database:
    # Hauseholds where reference person is retired:  257499
    # We assume that the refernece persone responded to our questionnaire

     pop.pension <-  data.frame("pension"=levels(all.design$pension), 
                          Freq=c(households-257499,
                                 257499
                          )    )

     comparision.pop.pension<-  rbind (  table(all.design$beruf_7)/length(all.design$beruf_7)   , 
                               pop.pension[,2]/households )

     rownames(comparision.pop.pension)<-c("survey", "Official Statistic")



      z <- (comparision.pop.pension[1,]-comparision.pop.pension[2,])/((comparision.pop.pension[2,]*(1-comparision.pop.pension[2,]))/385)^.5
      p.value<-(1-(pnorm(abs(z))))*2
      comparision.pop.pension<-cbind(comparision.pop.pension[,1],c(p.value[1],NA),
                               comparision.pop.pension[,2],c(p.value[2],NA)
                                )
  ########
  # Age 
  # data from open.wien.at    
    ageVienna2012<-data.frame(
        "age"=c("0 Jahre","1 Jahr","2 Jahre","3 Jahre","4 Jahre","5 Jahre","6 Jahre","7 Jahre","8 Jahre","9 Jahre","10 Jahre","11 Jahre","12 Jahre","13 Jahre","14 Jahre","15 Jahre","16 Jahre","17 Jahre","18 Jahre","19 Jahre","20 Jahre","21 Jahre","22 Jahre","23 Jahre","24 Jahre","25 Jahre","26 Jahre","27 Jahre","28 Jahre","29 Jahre","30 Jahre","31 Jahre","32 Jahre","33 Jahre","34 Jahre","35 Jahre","36 Jahre","37 Jahre","38 Jahre","39 Jahre","40 Jahre","41 Jahre","42 Jahre","43 Jahre","44 Jahre","45 Jahre","46 Jahre","47 Jahre","48 Jahre","49 Jahre","50 Jahre","51 Jahre","52 Jahre","53 Jahre","54 Jahre","55 Jahre","56 Jahre","57 Jahre","58 Jahre","59 Jahre","60 Jahre","61 Jahre","62 Jahre","63 Jahre","64 Jahre","65 Jahre","66 Jahre","67 Jahre","68 Jahre","69 Jahre","70 Jahre","71 Jahre","72 Jahre","73 Jahre","74 Jahre","75 Jahre","76 Jahre","77 Jahre","78 Jahre","79 Jahre","80 Jahre","81 Jahre","82 Jahre","83 Jahre","84 Jahre","85 Jahre","86 Jahre","87 Jahre","88 Jahre","89 Jahre","90 Jahre","91 Jahre","92 Jahre","93 Jahre","94 Jahre","95 Jahre und aelter"),
              "years"=0:95,
         "number"=c(17695,18174,17599,17275,17090,16846,16448,16341,15901,16014,15774,15550,15637,15473,15555,16163,16261,16610,17939,19763,22030,23588,24412,25213,26242,26277,26535,27348,27626,27926,28190,27846,26318,25478,24730,24399,24486,25084,24937,25066,25719,26368,27080,28108,28532,27959,27934,27920,27698,27355,26237,24883,24396,23159,22030,21450,20818,19723,18769,18190,17606,17377,18138,19310,20126,19173,14060,17184,19323,17949,18768,19153,19958,14853,10047,9020,8616,8383,8166,8192,8267,8095,7824,7264,6825,6527,6317,5807,5106,4568,3748,2940,2163,1122,726,2462)
           )

   # number of persons in Vienna of 65 or more years
       sum(ageVienna2012$number[ageVienna2012$years>64]) # 292606
       sum(ageVienna2012$number[ageVienna2012$years<16]) # 263535

    # age categories weighted by the number of households relative to sum of persons in all age categories
    # as households over sum of persons in all age groups is 0.5044, each observations counts only for half, to normalize to the number of households
    # this complication is necessary because age is person and not household specific   
     # these are used for raking
       pop.ageCategories  <-  data.frame("ageCategories"=levels(all.design$ageCategories), 
                           "Freq"=c( sum(ageVienna2012$number[ageVienna2012$years<31])*(households/sum(ageVienna2012$number, na.rm=TRUE)),
                                     sum(ageVienna2012$number[ageVienna2012$years>30 & ageVienna2012$years<61])*(households/sum(ageVienna2012$number, na.rm=TRUE)),
                                     sum(ageVienna2012$number[ageVienna2012$years>60])*(households/sum(ageVienna2012$number, na.rm=TRUE)) )
                        )
    # unweighted age categories. 
    # these are used to compare the popualtion shares
       pop.ageCategoriesOrig  <-  data.frame("ageCategories"=levels(all.design$ageCategories), 
                                  "Freq"=c( sum(ageVienna2012$number[ageVienna2012$years<31]),
                                            sum(ageVienna2012$number[ageVienna2012$years>30 & ageVienna2012$years<61]),
                                            sum(ageVienna2012$number[ageVienna2012$years>60]) )
                           )

    comparision.ageCategories<-  rbind (table(cut(all.design$age, c(0,30,60,150)))/nrow(all.design), 
                                pop.ageCategoriesOrig[,2]/sum(pop.ageCategoriesOrig[,2])
                                )
       

   rownames(comparision.ageCategories)<-c("survey", "Official Statistic")
   comparision.ageCategories


        z <- (comparision.ageCategories[1,]-comparision.ageCategories[2,])/((comparision.ageCategories[2,]*(1-comparision.ageCategories[2,]))/385)^.5
        p.value<-(1-(pnorm(abs(z))))*2
        comparision.ageCategories<-cbind(comparision.ageCategories[,1],c(p.value[1],NA),
                                    comparision.ageCategories[,2],c(p.value[2],NA),
                                    comparision.ageCategories[,3],c(p.value[3],NA)
                            )


    ############
    # Dogs
      # data from open.wien.at  
      # Number of dow owners  42989
      # I assume that in each houshold only one person 
      # registerd dogs

         pop.dogOwn <- data.frame("dogOwn"=c("no", "yes"), "Freq" =c(828382, 42989))
          comparision.dogOwn<-  rbind (  table(all.design$dogOwn)/length(all.design$dogOwn)   , 
                                    pop.dogOwn[,2]/households )
            rownames(comparision.dogOwn)<-c("survey", "Official Statistic")
            comparision.dogOwn
             z <- (comparision.dogOwn[1,2]-comparision.dogOwn[2,2])/((comparision.dogOwn[2,2]*(1-comparision.dogOwn[2,2]))/385)^.5
             p.value<-(1-(pnorm(z)))*2
             comparision.dogOwn<-cbind(comparision.dogOwn,c(p.value,NA) )
             z <- (comparision.dogOwn[1,]-comparision.dogOwn[2,])/((comparision.dogOwn[2,]*(1-comparision.dogOwn[2,]))/385)^.5
             p.value<-(1-(pnorm(abs(z))))*2
             comparision.dogOwn<-cbind(comparision.dogOwn[,1],c(p.value[1],NA),
                          comparision.dogOwn[,2],c(p.value[2],NA) )
    #########                        
     # Personal Income
      # Source: Statistik Austria       
      # http://www.statistik.at/web_de/statistiken/soziales/personen-einkommen/allgemeiner_einkommensbericht/index.html
      # StatAustr: Statistiken-> Soziales->Personeneinkommen->Allgemeiner Einkommensbericht
      # Vienna 2011: Net income employed:

        incomeMonthNetVienna<-data.frame(
            "Incomshare"=c("NumberPersons","25%lowerthan","50%lowerthan","75%lowerthan"),
            "EmplEuro2011"=round(c(776321, 7982/12,  18257/12,  27367/12)),
            "SelfEmplEuro2009"=round(c(66454 , 5089/12,  11608/12,  21267/12)),
            "PensionEuro2011"=round(c(393760 , 11306/12,  17646/12,  23919/12))
             )
         sum(incomeMonthNetVienna[1,2:4] ) # 123,6535
           # < 16 years: 263,535
           #  ---> meaning about  200.000 persons are missing. Assume this does not introduce too much distortion
           # Average income (without governmental transfers except for pensions)
         shares<-matrix(incomeMonthNetVienna[1,2:4]/sum(incomeMonthNetVienna[1,2:4] ))
         sum(incomeMonthNetVienna[2,2:4]*shares) # 25% have a personal Net income below 740.2555
         sum(incomeMonthNetVienna[3,2:4]*shares) # 50% have a personal Net income below 1474.987
         sum(incomeMonthNetVienna[4,2:4]*shares) # 75% have a personal Net income below 2161.935

         pop.income  <-  data.frame("personal_incom_quartil"=levels(all.design$personal_incom_quartil), 
                                     "Freq"=c( 0.25*households,
                                               0.25*households,
                                               0.25*households,
                                               0.25*households) )
        ############################### 
          # Household income
          # Source: Statistik Autria
          # http://www.statistik.at/web_de/statistiken/soziales/haushalts-einkommen/index.html
           pop.hh_incom_equ_percentil  <-  data.frame("hh_incom_equ_percentil"=levels(all.design$hh_incom_equ_percentil), 
                                           "Freq"=c( 0.1 *households,
                                                     0.15*households,
                                                     0.25*households,
                                                     0.25*households,
                                                     0.15*households, 
                                                     0.1 *households) )
           comparision.hh_incom_equ_percentil<-  rbind (table(all.design$hh_incom_equ_percentil)/sum(table(all.design$hh_incom_equ_percentil)), 
                                                       pop.hh_incom_equ_percentil[,2]/sum(pop.hh_incom_equ_percentil[,2])
                                                 )
                                                         
                        rownames(comparision.hh_incom_equ_percentil)<-c("survey", "Official Statistic")
                        comparision.hh_incom_equ_percentil
            z <- (comparision.hh_incom_equ_percentil[1,]-comparision.hh_incom_equ_percentil[2,])/((comparision.hh_incom_equ_percentil[2,]*(1-comparision.hh_incom_equ_percentil[2,]))/385)^.5
            p.value<-(1-(pnorm(abs(z))))*2
            comparision.hh_incom_equ_percentil<-cbind(comparision.hh_incom_equ_percentil[,1],c(p.value[1],NA),
                                    comparision.hh_incom_equ_percentil[,2],c(p.value[2],NA),
                                    comparision.hh_incom_equ_percentil[,3],c(p.value[3],NA),
                                    comparision.hh_incom_equ_percentil[,4],c(p.value[4],NA),
                                    comparision.hh_incom_equ_percentil[,5],c(p.value[5],NA),
                                    comparision.hh_incom_equ_percentil[,6],c(p.value[5],NA)
                            )
           #### household members
            # http://www.statistik.at/web_de/statistiken/bevoelkerung/haushalte_familien_lebensformen/haushalte/023302.html
            # households in Vienna:               871371
            # davon mit 2 Personen       248400: 248400/households=0.29
            # davon mit 3 Personen       107200: 107200/households=0.12 
            # davon mit 4 Personen        67600:  67600/households=0.08 
            # davon mit 5 und mehr        42300:  42300/households=0.04   
  
            pop.haushaltsgroesse  <-  data.frame("hh_persons_STATaust"=levels(all.design$hh_persons_STATaust), 
                       "Freq"=c( (0.46*households+8713.7
                                    ),0.29*households,0.12*households, 0.08*households, 0.04*households) )

            comparision.haushaltsgroesse<-  rbind (table(all.design$hh_persons_STATaust)/sum(table(all.design$hh_persons_STATaust)), 
                                          pop.haushaltsgroesse[,2]/sum(pop.haushaltsgroesse[,2])
                              )
                              
             rownames(comparision.haushaltsgroesse)<-c("survey", "Official Statistic")
             comparision.haushaltsgroesse
              z <- (comparision.haushaltsgroesse[1,]-comparision.haushaltsgroesse[2,])/((comparision.haushaltsgroesse[2,]*(1-comparision.haushaltsgroesse[2,]))/385)^.5
              p.value<-(1-(pnorm(abs(z))))*2
              comparision.haushaltsgroesse<-cbind(comparision.haushaltsgroesse[,1],c(p.value[1],NA),
                                    comparision.haushaltsgroesse[,2],c(p.value[2],NA),
                                    comparision.haushaltsgroesse[,3],c(p.value[3],NA),
                                    comparision.haushaltsgroesse[,4],c(p.value[4],NA),
                                    comparision.haushaltsgroesse[,5],c(p.value[5],NA)
                            )
              ############## 
              # gender
              # Source: data provided by the City of Vienna on Zaehlgebietslevel. Data are based on Statistik Austria data 
             pop.gender <- data.frame("gender"=levels(all.design$gender),
                          "Freq"  = c(452923.3, 418447.7))

             comparison.gender <- rbind(0.5197824,
              sum(all.design$gender=="w", na.rm=TRUE)/sum(all.design$gender=="w"|all.design$gender=="m", na.rm=TRUE)
                   ) 
             rownames(comparison.gender)<-c("survey", "Official Statistic")
             comparison.gender
             z <- (comparison.gender[1,]-comparison.gender[2,])/((comparison.gender[2,]*(1-comparison.gender[2,]))/385)^.5
             p.value<-(1-(pnorm(abs(z))))*2
             comparison.gender<-cbind(comparison.gender[,1],c(p.value[1],NA))
   
  #################                         )
     # put all comparisions between sample and population in a single table
      comparison.all<-rbind(
         c("No","","Yes"," "," "," ", "","", "", "","", ""),
         cbind(round(comparision.dogOwn, digits=2),matrix(" ",ncol=8,nrow=2) ),
         c("Lower half","","Higher half"," "," "," ", "","", "", "","", ""),
         cbind(round(comparision.treeDensityClasses, digits=2),matrix(" ",ncol=8,nrow=2)),
         c("No","","Yes", " "," "," ", "","", "", "","", ""),
         cbind(round(comparision.pop.pension, digits=2),matrix(" ",ncol=8,nrow=2)),
         c("No car","","One car", "","Two or more cars",""," "," "," ","","",""),
         cbind(round(comparision.car, digits=2),matrix(" ",ncol=6,nrow=2)),
         c("1","","2","", "3","","4","",">5",""," ",""),
         cbind(round(comparision.haushaltsgroesse, digits=2),matrix(" ",ncol=2,nrow=2) ),
         c("<10,032","","10,032-14,107","", "14,108-20,104","","20,105-29,353","","29,353-40,360","", ">40,360",""),
             round(comparision.hh_incom_equ_percentil, digits=2),
         c("mean", " "," "," "," ", "","", "", "","", "",""),
         cbind(round(comparison.gender, digits=2),matrix(" ",ncol=10,nrow=2)),
         c("0-30","","31-60","","over 60",""," "," "," ","","",""),
         cbind(round(comparision.ageCategories,digits=2),matrix(" ",ncol=6,nrow=2)),
         c("Mandatory or Lehre","", "Fachschule","", "Matura","", "University",""," ",""," ",""),
         cbind(round(comparision.education, digits=2), matrix("",ncol=4,nrow=2))
           )
      colnames(comparison.all)<-NULL
      rownames(comparison.all)[c(1,4,7,10,13,16,19,22,25)]<-
                c("Dog ownership",
                  "Retiered HH represnetativ",
                  "Tree density zaehlgebiet",
                  "Car ownership",
                  "Houshold members",
                  "HH income (Euro)",
                  "Share female",
                  "Age groups (shares)",
                  "Education level (shares)")

    ### Table 3: 
       table3<-comparison.all


  # generate the design objects with raking
      uhi.raked_all <-  rake(uhi_design_all, sample.margins=list(~car, ~dogOwn, ~pension,~gender,~ageCategories,~education2 ,~treeDensityClasses), 
                       population.margins=list(pop.pkw,  pop.dogOwn, pop.pension,pop.gender,pop.ageCategories,pop.education, pop.treeDensityClasses),  
                       control = list(maxit =50,  epsilon = 1, verbose=FALSE ) )

      uhi.raked_tree <- rake(uhi_design_tree, sample.margins=list(~car, ~dogOwn, ~pension,~gender,~ageCategories,~education2,~treeDensityClasses),
                       population.margins=list(pop.pkw,  pop.dogOwn, pop.pension,pop.gender,pop.ageCategories,pop.education, pop.treeDensityClasses),
                       control = list(maxit =50,  epsilon = 1, verbose=FALSE ) )

      uhi.raked_foun <- rake(uhi_design_foun, sample.margins=list(~car, ~dogOwn, ~pension,~gender,~ageCategories,~education2,~treeDensityClasses),
                       population.margins=list(pop.pkw,  pop.dogOwn, pop.pension,pop.gender,pop.ageCategories,pop.education, pop.treeDensityClasses),
                       control = list(maxit =100,  epsilon = 1, verbose=FALSE ) )

      uhi.raked_both <- rake(uhi_design_both, sample.margins=list(~car, ~dogOwn, ~pension,~gender,~ageCategories,~education2,~treeDensityClasses),
                       population.margins=list(pop.pkw,  pop.dogOwn, pop.pension,pop.gender,pop.ageCategories,pop.education, pop.treeDensityClasses),
                       control = list(maxit =50,  epsilon = 1, verbose=FALSE ) )



 
# additional table not shown in the article 
 WTPmeanTree<-svymean( ~WTPm_tree, uhi.raked_tree, na.rm=TRUE)
 WTPmeanFoun<-svymean( ~WTPm_foun, uhi.raked_foun, na.rm=TRUE)
 WTPmeanBoth<-svymean( ~WTPm_both, uhi.raked_both, na.rm=TRUE)
 
 WTPtable<-
 matrix(c(
 WTPmeanTree,(attr(WTPmeanTree,"var"))^.5,
 WTPmeanFoun,(attr(WTPmeanFoun,"var"))^.5,
 WTPmeanBoth,(attr(WTPmeanBoth,"var"))^.5
          ), ncol=3, byrow=FALSE)
 
 colnames(WTPtable) <-c("Trees",  "Fountains", "Both")
 rownames(WTPtable) <-c("Mean WTP", "S.E.")
 
# ## One way analysis not shown in the article
  
      
      # Have you ever experienced a heat period in Vienna?
        svymean( ~X1_heat_vienna , design=uhi.raked_all, na.rm=TRUE)
      # Do you mainly work outdoors? 
        svymean( ~X2_arbeit_freien, design=uhi.raked_all, na.rm=TRUE)
      # How did the last heat period influence your well-being?
        # Share of answers "rather negative"&"negative
        sum((svytable( ~X3_effect_heat_wohl_wohn, design=uhi.raked_all)/households)[4:5])
        sum((svytable( ~X3_effect_heat_wohl_str, design=uhi.raked_all) /households)[4:5])
        sum((svytable( ~X3_effect_heat_wohl_arb, design=uhi.raked_all) /households)[4:5])
      # Have you ever noticed the cooling effect of trees?
        svymean( ~X4a_trees_cool, design=uhi.raked_all, na.rm=TRUE)
      # Have you used a drinking fountain in the last 12 months?
        svymean( ~X4b_used_fountain, design=uhi.raked_all, na.rm=TRUE)
      # What have you done to protect yourself during the last heat period?
         
     par(mar=c(13,2,3,2))

         barplot(
              height=100*c(
               svymean( ~X5_heat_mitigated_1, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_2, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_3, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_4, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_5, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_6, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_7, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_8, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_9, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_10, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_11, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_12, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_13, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_14, design=uhi.raked_all, na.rm=TRUE)[1],
               svymean( ~X5_heat_mitigated_15, design=uhi.raked_all, na.rm=TRUE)[1]),
              names.arg=c("left town","slept out of town","more evenings outdoors", "less daytime outdoors",
                          "used fan", "closed curtains", " used aircondition at home", "aired flat in morning & at night",
                          "turned off electric appliances", "re-secduled working time", "worked less", "changed diet", 
                          "drank more", "wore lighter coloured cloths","used headdress")
              , las=3,
              ylab="%",# rotate names to vertical
              ylim=c(0,100)
              )
       # add the %
       text(x=seq(.7,15*1.2,by=1.2),y=12,as.character(round(c(
         svymean( ~X5_heat_mitigated_1, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_2, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_3, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_4, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_5, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_6, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_7, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_8, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_9, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_10, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_11, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_12, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_13, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_14, design=uhi.raked_all, na.rm=TRUE)[1],
         svymean( ~X5_heat_mitigated_15, design=uhi.raked_all, na.rm=TRUE)[1])*100))
           )
     #restore default
       par(mar=c(5,4,4,2) + 0.1)  

      # Which measures against heat have you noticed in Vienna?
     

        par(mar=c(13,2,3,2))

         barplot(
          height=100*c(
            svymean( ~X6_heat_measures_1, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_2, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_3, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_4, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_5, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_6, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_7, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_8, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_9, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_10, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_11, design=uhi.raked_all, na.rm=TRUE)[1]
                ),
             names.arg=c("trees on the street","facade greening","rails greening", "green along sideway",
              "roof greening", "shading of sideway", "brightening of street-surfaces", "access to water (e.g. Danube)",
              "drinking fountains", "air-conditioning public transport", "hints for behaviour" )
            , las=3, # rotate names to vertical
          ylab="%",# rotate names to vertical
          ylim=c(0,100) 
           )

     # add the %
          text(x=seq(.7,11*1.2,by=1.2),y=20,as.character(round(100*c(
            svymean( ~X6_heat_measures_1, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_2, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_3, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_4, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_5, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_6, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_7, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_8, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_9, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_10, design=uhi.raked_all, na.rm=TRUE)[1],
            svymean( ~X6_heat_measures_11, design=uhi.raked_all, na.rm=TRUE)[1]
            
             )))
           )

        #restore default
        par(mar=c(5,4,4,2) + 0.1)  

  ### Oneway WTP
    #Trees
    svyquantile( ~WTPm_tree, uhi.raked_tree, quantiles=c(c(.25,.5,.75)), na.rm=TRUE)
    svymean( ~WTPm_tree, uhi.raked_tree, na.rm=TRUE)
      cdf.est<- svycdf(~ WTPm_tree, uhi.raked_tree)
      cdf.samp<- ecdf(all.design$WTPm_tree[ all.design$scenario=="trees"])
      plot(cdf.est[[1]], lwd=2, col.vert="grey60", col.hor="grey60",
           do.points=FALSE, xlab="WTP", main="Trees", ylab="share")
      lines(cdf.samp, do.points=FALSE, lwd=2, col="red")
      legend("bottomright", lwd=c(2,2), bty="n", 
             col=c("grey60", "red"), legend=c("weighted estimate", "unweighted estimate" )
             )
    #Fountains
    svyquantile( ~WTPm_foun, uhi.raked_foun, quantiles=c(c(.25,.5,.75)), na.rm=TRUE)
    svymean( ~WTPm_foun, uhi.raked_foun, na.rm=TRUE)
      cdf.est<- svycdf(~ WTPm_foun, uhi.raked_foun)
      cdf.samp<- ecdf(all.design$WTPm_foun[ all.design$scenario=="fountains"])
      plot(cdf.est[[1]], lwd=2, col.vert="grey60", col.hor="grey60",
          do.points=FALSE, xlab="WTP", main="Fountains", ylab="share")
      lines(cdf.samp, do.points=FALSE, lwd=2, col="red")
       legend("bottomright", lwd=c(2,2), bty="n", 
       col=c("grey60", "red"), legend=c("weighted estimate", "unweighted estimate" )
         )


    #Both
    svyquantile( ~WTPm_both, uhi.raked_both, quantiles=c(c(.25,.5,.75)), na.rm=TRUE)
    svymean( ~WTPm_both, uhi.raked_both, na.rm=TRUE)
     cdf.est<- svycdf(~ WTPm_both, uhi.raked_both)
     cdf.samp<- ecdf(all.design$WTPm_both[ all.design$scenario=="both"])
     plot(cdf.est[[1]], lwd=2, col.vert="grey60", col.hor="grey60",
         do.points=FALSE, xlab="WTP", main="Both", ylab="share")
     lines(cdf.samp, do.points=FALSE, lwd=2, col="red")
     legend("bottomright", lwd=c(2,2), bty="n", 
       col=c("grey60", "red"), legend=c("weighted estimate", "unweighted estimate" )
       )
     #how the contribution is split
       svyquantile( ~X8c_wtp_ratio_trees, uhi.raked_both, quantiles=c(c(.25,.5,.75)), na.rm=TRUE)
       svymean(     ~X8c_wtp_ratio_trees, uhi.raked_both, na.rm=TRUE)



   ########################
   ## Szenario Trees

  plot(
    x= cumsum(table(all.design$WTPm_both )[7:1]) ,
    y= names(table(all.design$WTPm_both)[7:1]),
    xlim=c(0,130),
    col="darkorange",   
    xlab="No. agreeing Respondents",
    ylab="Max. monthly fee in Euro",
    #main="",
    type="S",
    lwd=4
   )
  abline(h=0)
  abline(v=0)

  lines(
    x= cumsum(table(all.design$WTPm_tree)[7:1]) ,
    y= names(table(all.design$WTPm_tree)[7:1]),
    col="darkgreen",   
    type="S",
    lwd=4
    )

  lines(
    x= cumsum(table(all.design$WTPm_foun)[6:1]) ,
    y= names(table(all.design$WTPm_foun)[6:1]),
  col="darkblue",   
  type="S",
  lwd=4
  )

  legend("topright", legend=c("Scenario 'Trees'","Scenario 'Fountains'","Scenario 'Trees&Fountains'"),
        col=c("darkgreen","darkblue","darkorange"),lty=1, lwd=3 )

    

  ### Do weighted mean tests

  ##### Trees
   # compare the two tree scenarios
   meanT10<-svymean(~WTPm_tree, subset(uhi.raked_tree,leveltrees=="10") )
   meanT50<-svymean(~WTPm_tree, subset(uhi.raked_tree,leveltrees=="50") )
   T50test<-svyttest(WTPm_tree~leveltrees, uhi.raked_tree)
   # no significant difference
   # drop those which are 0
   svymean(~WTPm_tree, subset(uhi.raked_tree,leveltrees=="10"&WTPm_tree>0) )
   svymean(~WTPm_tree, subset(uhi.raked_tree,leveltrees=="50"&WTPm_tree>0) )
   svyttest(WTPm_tree~leveltrees, subset(uhi.raked_tree,WTPm_tree>0) )
   # still no significant difference

    # is there a difference in the WTP depending on eduacation?
      # compare "university" to all other levels of education
      svyttest(WTPm_tree~I(education2=="4"), uhi.raked_tree)
        # not significant
       # compare "university" to "mandatory school & apprenticeship"
      svyttest(WTPm_tree~I(education2=="4"), subset(uhi.raked_tree, education2 %in% c("1","4")) )
        #significant on a 10%level
 
   ##### Fountains

    meanFhalf<-svymean(~WTPm_foun, subset(uhi.raked_foun,levelfoun=="um die Hälfte erhöht") )
    meanFdoub<-svymean(~WTPm_foun, subset(uhi.raked_foun,levelfoun=="verdoppelt") )
    Fdoubtest<-svyttest(WTPm_foun~levelfoun, uhi.raked_foun)
    

   # drop those that are zero
     svymean(~WTPm_foun, subset(uhi.raked_foun,levelfoun=="um die Hälfte erhöht"&WTPm_foun>0))
     svymean(~WTPm_foun, subset(uhi.raked_foun,levelfoun=="verdoppelt"&WTPm_foun>0) )
     svyttest(WTPm_foun~levelfoun, subset(uhi.raked_foun,WTPm_foun>0) )
   # significant on a 10% level

   # is there a difference in the WTP depending on eduacation?
   # compare "university" to all other levels of education
    svyttest(WTPm_foun~I(education2=="4"), uhi.raked_foun)
     # not significant
   # compare "university" to "mandatory school & apprenticeship"
     svyttest(WTPm_foun~I(education2=="4"), subset(uhi.raked_foun, education2 %in% c("1","4")) )
     #significant on a 10% level


 #### Comparison of scenarios for "both"
   meanBtree10founDoub<-svymean(~WTPm_both, subset(uhi.raked_both,levelboth=="tree10founDoub") )
   meanBtree10founHalf<-svymean(~WTPm_both, subset(uhi.raked_both,levelboth=="tree10founHalf") )
   meantree50founDoub <-svymean(~WTPm_both, subset(uhi.raked_both,levelboth=="tree50founDoub") )
   meantree50founHalf <-svymean(~WTPm_both, subset(uhi.raked_both,levelboth=="tree50founHalf") )

   Btree10founDoubtest<-svyttest(WTPm_both~I(levelboth=="tree10founDoub"), uhi.raked_both)
   Btree10founHalftest<-svyttest(WTPm_both~I(levelboth=="tree10founHalf"), uhi.raked_both)
   Btree50founDoubtest<-svyttest(WTPm_both~I(levelboth=="tree50founDoub"), uhi.raked_both)
   Btree50founHalftest<-svyttest(WTPm_both~I(levelboth=="tree50founHalf"), uhi.raked_both)
   # none is significantly different from all others
   svyttest(WTPm_both~I(levelboth=="tree50founDoub"), subset(uhi.raked_both, levelboth %in% c("tree10founHalf","tree50founDoub")) )
   #no sign. difference between the two extreme scenarios (10%Trees&Half more fountain 
   #                           compared to 50%Trees & double fountains) 
   svyttest(WTPm_both~I(levelboth=="tree50founHalf"), subset(uhi.raked_both, levelboth %in% c("tree10founDoub","tree50founHalf")) )
   # also no significant difference between the most popular (+50%Tree+halfFountan)
   # an least popular scenarios (+10%Tree+doubleFoutntain)
  # make a table
  

  scaleTest <- rbind(
     c(coef(meanT10),coef(meanT50),T50test$estimate,coef(meanFhalf),coef(meanFdoub),Fdoubtest$estimate, coef(meanBtree10founHalf), Btree10founHalftest$estimate, coef(meanBtree10founDoub), Btree10founDoubtest$estimate,coef(meantree50founHalf), Btree50founHalftest$estimate, coef( meantree50founDoub),Btree50founDoubtest$estimate),
     c(SE(meanT10),SE(meanT50),T50test$p.value,SE(meanFhalf),SE(meanFdoub),Fdoubtest$p.value, SE(meanBtree10founHalf), Btree10founHalftest$p.value, SE(meanBtree10founDoub), Btree10founDoubtest$p.value,SE(meantree50founHalf), Btree50founHalftest$p.value, SE( meantree50founDoub),Btree50founDoubtest$p.value),
     c(
    length(all.design$WTPm_tree[all.design$scenario=="trees"&all.design$leveltrees==10]),
    length(all.design$WTPm_tree[all.design$scenario=="trees"&all.design$leveltrees==50]),NA,
    length(all.design$WTPm_foun[all.design$scenario=="fountains"&all.design$levelfoun=="um die Hälfte erhöht"]),
    length(all.design$WTPm_foun[all.design$scenario=="fountains"&all.design$levelfoun=="verdoppelt"]),NA,
    length(all.design$WTPm_both[all.design$scenario=="both"&all.design$levelboth=="tree10founHalf"]) , NA,
    length(all.design$WTPm_both[all.design$scenario=="both"&all.design$levelboth=="tree10founDoub"]) , NA,
    length(all.design$WTPm_both[all.design$scenario=="both"&all.design$levelboth=="tree50founHalf"]) , NA,
    length(all.design$WTPm_both[all.design$scenario=="both"&all.design$levelboth=="tree50founDoub"]) , NA
    ) )

  
  rownames(scaleTest)<-c("Av. WTP","St.Er/p-val" , "No.Obs")
  colnames(scaleTest)<-c("10%T","50%%","Diff",
                         "50%F","100%F","Diff",
                         "10%T&50%F","Diff",
                         "10%T&100%F","Diff",
                         "50%T&50%F","Diff",
                         "50%T&100%F","Diff")

  
  
# save the relevant results for table 6  
 table6.row.b.est <- c(coef(meanT10),coef(meanT50),coef(meanFhalf),coef(meanFdoub))
 table6.row.b.se  <- c(SE(meanT10),  SE(meanT50),  SE(meanFhalf),  SE(meanFdoub)  )
 
   
  

 
  HHconsiderTreesReasonable <-svytable( ~X8_trees_yes,    design=uhi.raked_tree)
        # share "yes"
         HHconsiderTreesReasonable["1"]/households #
        # share "no"
         HHconsiderTreesReasonable["0"]/households #
        # not willing to pay
            HHconsiderTreesReasonableButDontPay<-svytable( ~X8a_valuation_treesEqual0,  design=uhi.raked_tree)["1"]
             TreesHHconsiderTreesReasonableButDontPay  <- HHconsiderTreesReasonableButDontPay/HHconsiderTreesReasonable["1"]
             TreesObjectFee     <-svytable( ~X8b_ObjectFee,  design=uhi.raked_tree)[1]/HHconsiderTreesReasonableButDontPay
             TreesCannotAfford  <-svytable( ~X8b_CannotAfford,  design=uhi.raked_tree)[1]/HHconsiderTreesReasonableButDontPay
             TreesCityShouldPay <-svytable( ~X8b_CityShouldPay,  design=uhi.raked_tree)[1]/HHconsiderTreesReasonableButDontPay
 
           TreesNotaffectedByHeat     <-svytable( ~X9_NotaffectedByHeat,     design=uhi.raked_tree)["1"]/HHconsiderTreesReasonable["0"]
           TreesDontLikeTreesInCity   <-svytable( ~X9_DontLikeTreesInCity,   design=uhi.raked_tree)["1"]/HHconsiderTreesReasonable["0"]
           TreesDontLikeTreesInCity   <-0 # because no observations, set to zero
           TreesTreesDontBeatHeat     <-svytable( ~X9_TreesDontBeatHeat,     design=uhi.raked_tree)["1"]/HHconsiderTreesReasonable["0"]
           TreesObjectReductionParking<-svytable( ~X9_ObjectReductionParking,design=uhi.raked_tree)["1"]/HHconsiderTreesReasonable["0"]
 
   HHconsiderFountainsReasonable <-svytable( ~X8_fountain_yes,    design=uhi.raked_foun)
        # share "yes"
         HHconsiderFountainsReasonable["1"]/households
 # share "no"
         HHconsiderFountainsReasonable["0"]/households # 
        # not willing to pay
            HHconsiderFountainsReasonableButDontPay<-svytable( ~X8a_valuation_fountEqual0,  design=uhi.raked_foun)["1"]
             FountHHconsiderFountainsReasonableButDontPay  <- HHconsiderFountainsReasonableButDontPay/HHconsiderFountainsReasonable["1"]
             FountsObjectFee     <-svytable( ~X8b_ObjectFee,     design=uhi.raked_foun)[1]/HHconsiderFountainsReasonableButDontPay
             FountCannotAfford   <-svytable( ~X8b_CannotAfford,  design=uhi.raked_foun)[1]/HHconsiderFountainsReasonableButDontPay
             FountCityShouldPay  <-svytable( ~X8b_CityShouldPay, design=uhi.raked_foun)[1]/HHconsiderFountainsReasonableButDontPay
 
           FountNotaffectedByHeat     <-svytable( ~X9_NotaffectedByHeat,     design=uhi.raked_foun)["1"]/HHconsiderFountainsReasonable["0"]
           FountDontLikeFountains     <-svytable( ~X9_DontLikeFountains,   design=uhi.raked_foun)["1"]/HHconsiderFountainsReasonable["0"]
           FountFountainsDontBeatHeat <-svytable( ~X9_FountainsDontBeatHeat,     design=uhi.raked_foun)["1"]/HHconsiderFountainsReasonable["0"]

 
      opinionsMeasures<- matrix(
         c(# first column "Tree"
           HHconsiderTreesReasonable["1"]/households,
           TreesHHconsiderTreesReasonableButDontPay,
           TreesObjectFee,   
           TreesCannotAfford,
           TreesCityShouldPay,
           HHconsiderTreesReasonable["0"]/households, 
           TreesNotaffectedByHeat,   
           NA, NA,
           TreesDontLikeTreesInCity, 
           TreesTreesDontBeatHeat,   
           TreesObjectReductionParking,
           # second column "Fount"
           HHconsiderFountainsReasonable["1"]/households,
           FountHHconsiderFountainsReasonableButDontPay,
           FountsObjectFee,
           FountCannotAfford,
           FountCityShouldPay, 
           HHconsiderFountainsReasonable["0"]/households, 
           FountNotaffectedByHeat,
           FountDontLikeFountains,
           FountFountainsDontBeatHeat,
           NA, NA, NA
           ), ncol=2, nrow=12         )
  
    colnames(opinionsMeasures)<-c("Trees","Fountains")
    rownames(opinionsMeasures)<-c(
      "ConsidersMeasureReasonable",
      "HHconsiderMeasureReasonableButDontPay",
      "DontPayBecauseObjectFees",
      "DontPayBecauseCannotAfford",
      "DontPayBecauseCityShouldPay",
      "ConsidersMeasureNOTReasonable",
      "NotResonableBecauseNotaffectedByHeat",
      "NotResonableBecauseDontLikeFountains",
      "NotResonableBecauseFountainsDontBeatHeat",
      "NotResonableBecauseDontLikeTreesInCity",
      "NotResonableTreesDontBeatHeat",
      "NotResonableObjectReductionParking"
      ) 
 
  # Table 4: 
    table4<-opinionsMeasures
 
 

###############################
# 
#  Inteval Regression
#
################################### 

 source("inveralLinearRegression_v002.R", encoding="UTF-8")

  table5
 
 # in the article there is a short note that there is hardly any effect of dropping
 # "protest votes". This can be seen by running the following code. If you run this code
 # also the rest of the results will be based on dropped "protest votes"
 # source("inveralLinearRegression_whenDroppingProtestVotes_v002.R", encoding="UTF-8")

###############################
# 
#  Bootstrapping:
#
###############################
 ### do weighted bootstraping
   useWeights<-TRUE
     source("bootstrapping_v003.R", encoding="UTF-8" )
   # Save results for weighted bootstrapping
     boot.Tree.weighted<-boot.Tree
     boot.Foun.weighted<-boot.Foun
     boot.Both.weighted<-boot.Both
     boot.Join.weighted<-boot.Join
 
   # Save weighted bootstrap coefficients 
     # use a modified summary function to assess the summary statistics directly
      source("boot.summary.modified.R", encoding="UTF-8" )
   boot.Tree.coef.weighted<-boot.summary.Uli(boot.Tree.weighted)
   boot.Foun.coef.weighted<-boot.summary.Uli(boot.Foun.weighted)
   boot.Both.coef.weighted<-boot.summary.Uli(boot.Both.weighted)
   boot.Join.coef.weighted<-boot.summary.Uli(boot.Join.weighted)

 ## caluclate unweighted bootstraps
   useWeights<-FALSE
    source( "bootstrapping_v003.R", encoding="UTF-8" )
    # Save results for unweighted bootstrapping
     boot.Tree.unweighted<-boot.Tree
     boot.Foun.unweighted<-boot.Foun
     boot.Both.unweighted<-boot.Both
     boot.Join.unweighted<-boot.Join

 # save unweighted bootstraps coefficients
   boot.Tree.coef.unweighted<-boot.summary.Uli(boot.Tree.unweighted)
   boot.Foun.coef.unweighted<-boot.summary.Uli(boot.Foun.unweighted)
   boot.Both.coef.unweighted<-boot.summary.Uli(boot.Both.unweighted)
   boot.Join.coef.unweighted<-boot.summary.Uli(boot.Join.unweighted)

 ### Make a table with all bootstap results

   boot.all.coef<-rbind(
   boot.Tree.coef.weighted,
   boot.Foun.coef.weighted,
   boot.Both.coef.weighted,
   boot.Join.coef.weighted,
   boot.Tree.coef.unweighted,
   boot.Foun.coef.unweighted,
   boot.Both.coef.unweighted,
   boot.Join.coef.unweighted
    )

  rownames(boot.all.coef)<- c("T10Weight", "T50Weight",
                                 "F50Weight","F100Weight", 
                                 "T10F50Weight", "T10F100Weight", "T50F50Weight", "T50F100Weight",
                                 "TrWeight", "FoWeight", "BoWeight",
                                 "T10Unweight", "T50Unweight",
                                 "F50Unweight","F100Unweight", 
                                 "T10F50Unweight", "T10F100Unweight", "T50F50Unweight", "T50F100Unweight",
                                 "TrUnweight", "FoUnweight", "BoUnweight"
                                 )
  
  colnames(boot.all.coef)<- c("Est.WTP.without.bootst.", 
                              "Bias.without.bootst.",
                              "St.Error",
                              "Est.WTP.with.bootst.")
  boot.all.coef<-boot.all.coef[,c(1,4,3,2)]
 
  
  table6.row.c.est<- c(boot.Tree.coef.unweighted[1,4],  boot.Tree.coef.unweighted[2,4], boot.Foun.coef.unweighted[1,4], boot.Foun.coef.unweighted[2,4])
  table6.row.c.se <- c(boot.Tree.coef.unweighted[1,3],  boot.Tree.coef.unweighted[2,3], boot.Foun.coef.unweighted[1,3], boot.Foun.coef.unweighted[2,3])
  table6.row.d.est<- c(boot.Tree.coef.weighted[1,4],    boot.Tree.coef.weighted[2,4],   boot.Foun.coef.weighted[1,4],   boot.Foun.coef.weighted[2,4])
  table6.row.d.se <- c(boot.Tree.coef.weighted[1,3],    boot.Tree.coef.weighted[2,3],   boot.Foun.coef.weighted[1,3],   boot.Foun.coef.weighted[2,3])
  
  table6.row.a.est <- c(mean(all.design$WTPm_tree[all.design$leveltrees==10], na.rm=TRUE), mean(all.design$WTPm_tree[all.design$leveltrees==50], na.rm=TRUE), mean(all.design$WTPm_foun[all.design$levelfoun=="um die Hälfte erhöht"], na.rm=TRUE),mean(all.design$WTPm_foun[all.design$levelfoun=="verdoppelt"], na.rm=TRUE))  
  table6.row.a.se  <- c(  sd(all.design$WTPm_tree[all.design$leveltrees==10], na.rm=TRUE)/length(all.design$WTPm_tree[all.design$leveltrees==10]),   sd(all.design$WTPm_tree[all.design$leveltrees==50], na.rm=TRUE)/length(all.design$WTPm_tree[all.design$leveltrees==50]),   sd(all.design$WTPm_foun[all.design$levelfoun=="um die Hälfte erhöht"], na.rm=TRUE)/length(all.design$WTPm_foun[all.design$levelfoun=="um die Hälfte erhöht"]),  sd(all.design$WTPm_foun[all.design$levelfoun=="verdoppelt"], na.rm=TRUE)/length(all.design$WTPm_foun[all.design$levelfoun=="verdoppelt"]))  
  
   

  table6 <- rbind(
           table6.row.a.est,
           table6.row.a.se,
           table6.row.b.est,
           table6.row.b.se,
           table6.row.c.est,
           table6.row.c.se,
           table6.row.d.est,
           table6.row.d.se, 
           table6.row.b.est - table6.row.d.est,
           table6.row.d.est/c(13500,65000,450,900)*households
         )
  colnames(table6)<- c("Trees10%", "Trees50%", "Fount50%", "Fount100%")
  rownames(table6)<- c("NaiveMean", "SE", "DesignBasedMean", "SE", "BootstrappUnweighted", 
                       "SE", "BootstrappWeighted", "SE", "Diff.b.d", "WTP per object per month times households")

  round(table6, 2)  

 # export tables to csv files  
 write.csv(table3, file="table3.csv")  
 write.csv(table4, file="table4.csv")    
 write.csv(table5, file="table5.csv")    
 write.csv(table6, file="table6.csv")         
 
